@@ -6,9 +6,9 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-use File::Which;
+use File::Which qw(which);
 
-our $VERSION = '0.0404';
+our $VERSION = '0.0405';
 
 
 
@@ -85,7 +85,7 @@ App::Provision::Tiny - Provision computers
 
 =head1 VERSION
 
-version 0.0404
+version 0.0405
 
 =head1 SYNOPSIS
 
